from PySide6.QtWidgets import QApplication, QTableWidget, QTableWidgetItem, QVBoxLayout, QPushButton, QWidget
from PySide6.QtCore import Qt

class MyWindow(QWidget):
    def __init__(self):
        super().__init__()

        self.data_list = [
            {'id': 53, 'step_sort': 0},
            {'id': 52, 'step_sort': 1},
            {'id': 51, 'step_sort': 2},
            {'id': 50, 'step_sort': 3},
        ]

        self.table = QTableWidget(len(self.data_list), 2)
        self.table.setHorizontalHeaderLabels(['ID', 'Step Sort'])
        self.populate_table()

        self.up_button = QPushButton("上移")
        self.lower_button = QPushButton("下移")

        self.up_button.clicked.connect(self.up)
        self.lower_button.clicked.connect(self.lower)

        layout = QVBoxLayout()
        layout.addWidget(self.table)
        layout.addWidget(self.up_button)
        layout.addWidget(self.lower_button)

        self.setLayout(layout)

    def populate_table(self):
        for row, data in enumerate(self.data_list):
            self.table.setItem(row, 0, QTableWidgetItem(str(data['id'])))
            self.table.setItem(row, 1, QTableWidgetItem(str(data['step_sort'])))

    def update_data(self):
        # 打印更新后的数据
        print("更新后的数据:")
        for index, data in enumerate(self.data_list):
            print(f"ID: {data['id']}, Step Sort: {index}")

    def up(self):
        row = self.table.currentRow()
        if row > 0:
            # 交换数据
            self.data_list[row], self.data_list[row - 1] = self.data_list[row - 1], self.data_list[row]
            # 更新表格
            self.populate_table()
            # 打印更新后的数据
            self.update_data()
            # 选择新的行
            self.table.setCurrentCell(row - 1, 0)

    def lower(self):
        row = self.table.currentRow()
        if row < len(self.data_list) - 1:
            # 交换数据
            self.data_list[row], self.data_list[row + 1] = self.data_list[row + 1], self.data_list[row]
            # 更新表格
            self.populate_table()
            # 打印更新后的数据
            self.update_data()
            # 选择新的行
            self.table.setCurrentCell(row + 1, 0)

if __name__ == "__main__":
    app = QApplication([])
    window = MyWindow()
    window.show()
    app.exec()



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-09-01 下午10:01
# @Author : 毛鹏
from mango_ui.init import *


class MangoMessage(QWidget):
    def __init__(self, parent, message, style):
        super().__init__(parent)
        self.setWindowFlags(Qt.FramelessWindowHint | Qt.Tool | Qt.WindowStaysOnTopHint)  # 保持在最上面
        self.setFixedHeight(30)

        layout = QVBoxLayout()
        layout.setContentsMargins(10, 0, 0, 0)
        self.label = QLabel(message)
        layout.addWidget(self.label)

        self.setLayout(layout)
        # 设置背景颜色和边框
        self.setStyleSheet(f"background-color: {style}; border: 1px solid lightgray; opacity: 0.39;")

        # 根据文字长度调整宽度
        font_metrics = QFontMetrics(self.label.font())
        text_width = font_metrics.boundingRect(message).width() + 25
        self.setFixedWidth(text_width)

        # 设置渐隐效果
        self.opacity = 1.7
        self.timer = QTimer(self)
        self.timer.timeout.connect(self.fade_out)
        self.timer.start(50)

    def fade_out(self):
        self.opacity -= 0.05
        self.setWindowOpacity(self.opacity)
        if self.opacity <= 0:
            self.close()
